<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * @link       www.skrotron.com
 * @since      1.0.7
 *
 * @package    Cart_Upsell_For_Woocommerce
 * @subpackage Cart_Upsell_For_Woocommerce/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Cart_Upsell_For_Woocommerce
 * @subpackage Cart_Upsell_For_Woocommerce/admin
 */
class Cart_Upsell_For_Woocommerce_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.7
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.7
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.7
	 * @param      string $plugin_name       The name of this plugin.
	 * @param      string $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version     = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.7
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Cart_Upsell_For_Woocommerce_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Cart_Upsell_For_Woocommerce_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/cart-upsell-for-woocommerce-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.7
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Cart_Upsell_For_Woocommerce_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Cart_Upsell_For_Woocommerce_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/cart-upsell-for-woocommerce-admin.js', array( 'jquery' ), $this->version, false );

	}

	/** Function to get color field.
	 *
	 * @param string $skrotronhook_suffix refer color.
	 */
	public function skrotron_enqueue_color_picker_for_cart_upsell( $skrotronhook_suffix ) {
		$handle = 'skrotron-color-handle.js';
		$list   = 'enqueued';
		if ( wp_script_is( $handle, $list ) ) {
			return;
		} else {
			wp_enqueue_style( 'wp-color-picker' );
			wp_enqueue_script( 'skrotron-color-handle', plugins_url( 'js/skrotron-color-handle.js', __FILE__ ), array( 'wp-color-picker' ), $this->version, true );
		}
	}

	/**
	 * Function belongs to cart upsell.
	 *
	 * @param      string $cart_upsell_options       Values.
	 */
	public function add_cart_upsell_option( $cart_upsell_options ) {
		global $post;
		$cart_upsell                                = get_post_meta( $post->ID, '_cart_upsell', true );
		$cart_upsell_options['cart_upsell_options'] = array(
			'id'            => '_cart_upsell',
			'wrapper_class' => 'show_if_simple',
			'label'         => __( 'Cart Upsell', 'woocommerce' ),
			'description'   => __( 'Cart Upsell allow you to show additional products on cart page.', 'woocommerce' ),
			'default'       => $cart_upsell,
		);
		return $cart_upsell_options;
	}

	/**
	 * Function belongs to cart upsell.
	 *
	 * @param      string $tabs       Values.
	 */
	public function cart_upsell_tabs( $tabs ) {
		$tabs['cart_upsell'] = array(
			'label'  => __( 'Cart Upsell', 'woocommerce' ),
			'target' => 'cart_upsell_options',
			'class'  => array( 'show_if_cart_upsell hide_if_simple hide_if_variable hide_if_grouped hide_if_external' ),
		);
		return $tabs;
	}

	/**
	 * Function belongs to cart upsell.
	 */
	public function cart_upsell_tab_content() {
		global $post;
		require plugin_dir_path( __FILE__ ) . 'partials/cart-upsell-for-woocommerce-admin-display.php';
	}

	/**
	 * Function belongs to cart upsell.
	 *
	 * @param      int $post_id       Values.
	 */
	public function save_cart_upsell_data_on_update( $post_id ) {
		if ( isset( $_POST['_nonce'] ) && '' !== $_POST['_nonce'] && wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['_nonce'] ) ), 'cart_upsell_nonce' ) ) {
			$_cart_upsell = isset( $_POST['_cart_upsell'] ) ? 'yes' : 'no';
			update_post_meta( $post_id, '_cart_upsell', $_cart_upsell );
		}
	}

	/**
	 * Function belongs to cart upsell.
	 */
	public function cart_upsell_get_dropdown_content() {
		if ( isset( $_POST['nonce'] ) && '' !== $_POST['nonce'] && wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['nonce'] ) ), 'cart_upsell_nonce' ) ) {
			$current_value = ( isset( $_REQUEST['currunt_val'] ) && '' !== $_REQUEST['currunt_val'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['currunt_val'] ) ) : '';
			if ( 'product' === $current_value ) {
				echo wp_json_encode( get_product_dd_cart_upsell() );
			} elseif ( 'category' === $current_value ) {
				echo wp_json_encode( get_category_dd_cart_upsell() );
			} else {
				echo wp_json_encode( get_upsell_cart_total_opt() );
			}
			die();
		}
	}

	/**
	 * Function belongs to cart upsell.
	 */
	public function cart_upsell_save_conditions() {
		if ( isset( $_POST['nonce'] ) && '' !== $_POST['nonce'] && wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['nonce'] ) ), 'cart_upsell_nonce' ) ) {
			$product_id         = ( isset( $_REQUEST['product_id'] ) && '' !== $_REQUEST['product_id'] ) ? intval( $_REQUEST['product_id'] ) : '';
			$condition_and_data = ( isset( $_REQUEST['condition_and_data'] ) && '' !== $_REQUEST['condition_and_data'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['condition_and_data'] ) ) : 'null';
			$condition_or_data  = ( isset( $_REQUEST['condition_or_data'] ) && '' !== $_REQUEST['condition_or_data'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['condition_or_data'] ) ) : 'null';

			$content            = ( isset( $_REQUEST['content'] ) && '' !== $_REQUEST['content'] ) ? wp_kses_post( wp_unslash( $_REQUEST['content'] ) ) : get_the_title( $product_id );
			$prd_url            = ( isset( $_REQUEST['prd_url'] ) && '' !== $_REQUEST['prd_url'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['prd_url'] ) ) : get_the_post_thumbnail_url( $product_id );
			$upsell_button_text = ( isset( $_REQUEST['upsell_button_text'] ) && '' !== $_REQUEST['upsell_button_text'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['upsell_button_text'] ) ) : 'Add To Cart';
			$bg_color           = ( isset( $_REQUEST['bg_color'] ) && '' !== $_REQUEST['bg_color'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['bg_color'] ) ) : '#000000';
			$content_color      = ( isset( $_REQUEST['content_color'] ) && '' !== $_REQUEST['content_color'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['content_color'] ) ) : '#FFFFFF';
			$button_color       = ( isset( $_REQUEST['button_color'] ) && '' !== $_REQUEST['button_color'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['button_color'] ) ) : '#FFFFFF';
			$button_bg_color    = ( isset( $_REQUEST['button_bg_color'] ) && '' !== $_REQUEST['button_bg_color'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['button_bg_color'] ) ) : '#96588a';
			$tranps             = ( isset( $_REQUEST['tranps'] ) && '' !== $_REQUEST['tranps'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['tranps'] ) ) : 0.8;

			$product_data_to_upsell = $content . '{{skrotron}}' . $prd_url . '{{skrotron}}' . $upsell_button_text . '{{skrotron}}' . $bg_color . '{{skrotron}}' . $content_color . '{{skrotron}}' . $button_color . '{{skrotron}}' . $button_bg_color . '{{skrotron}}' . $tranps;

			$added_and_data = get_post_meta( $product_id, 'cart_upsell_and_condition', true );
			if ( empty( $added_and_data ) ) {
				add_post_meta( $product_id, 'cart_upsell_and_condition', $condition_and_data );
			} else {
				update_post_meta( $product_id, 'cart_upsell_and_condition', $condition_and_data );
			}

			$added_or_data = get_post_meta( $product_id, 'cart_upsell_or_condition', true );
			if ( empty( $added_or_data ) ) {
				add_post_meta( $product_id, 'cart_upsell_or_condition', $condition_or_data );
			} else {
				update_post_meta( $product_id, 'cart_upsell_or_condition', $condition_or_data );
			}

			$added_prd_data = get_post_meta( $product_id, 'cart_upsell_product_data', true );
			if ( empty( $added_prd_data ) ) {
				add_post_meta( $product_id, 'cart_upsell_product_data', $product_data_to_upsell );
			} else {
				update_post_meta( $product_id, 'cart_upsell_product_data', $product_data_to_upsell );
			}

			echo esc_attr( 'success' );
			die();
		}
	}


}
