/**
 * All of the code for your public-facing JavaScript source
 * should reside in this file.
 *
 * @package           Cart_Upsell_For_Woocommerce
 * Note: It has been assumed you will write jQuery code here, so the
 * $ function reference has been prepared for usage within the scope
 * of this function.
 *
 * This enables you to define handlers, for when the DOM is ready:
 */

(function( $ ) {
	'use strict';

	/**
	 * All of the code for your admin-facing JavaScript source
	 * should reside in this file.
	 *
	 * Note: It has been assumed you will write jQuery code here, so the
	 * $ function reference has been prepared for usage within the scope
	 * of this function.
	 *
	 * This enables you to define handlers, for when the DOM is ready:
	 *
	 * $(function() {
	 *
	 * });
	 *
	 * When the window is loaded:
	 *
	 * $( window ).load(function() {
	 *
	 * });
	 *
	 * ...and/or other possibilities.
	 *
	 * Ideally, it is not considered best practise to attach more than a
	 * single DOM-ready or window-load handler for a particular page.
	 * Although scripts in the WordPress core, Plugins and Themes may be
	 * practising this, we should strive to set a better example in our own work.
	 */

	jQuery( document ).ready(
		function() {
			jQuery( 'input#_cart_upsell' ).change(
				function() {
					cart_upsell_trigger();
				}
			);
		}
	);

	jQuery( document ).on(
		'change',
		'#product-type',
		function() {
			if ( jQuery( this ).val() == 'simple' ) {
				cart_upsell_trigger();
			} else {
				jQuery( 'input#_cart_upsell' ).prop( 'checked', false );
			}
		}
	);

	jQuery( window ).on(
		'load',
		function(){
			cart_upsell_trigger();
		}
	);

	function cart_upsell_trigger(){
		var is_cart_upsell = jQuery( 'input#_cart_upsell:checked' ).size();
		jQuery( '.show_if_cart_upsell, #cart_upsell_options' ).hide();
		if ( is_cart_upsell ) {
			jQuery( '.show_if_cart_upsell' ).show();
			if ( jQuery( '.show_if_cart_upsell' ).hasClass( 'active' ) ) {
				jQuery( '#cart_upsell_options' ).show();
			}
		}
	}

	jQuery( document ).on(
		'change',
		'#cart_upsell_section #condition_type',
		function(){
			var currunt_event  = jQuery( this );
			var currunt_val    = jQuery( this ).val();
			var nonce          = jQuery( '#cart_upsell_section #_nonce' ).val();
			var equal_not_opt  = '<option value="equal">is equal to</option><option value="not_equal">is not equal to</option>';
			var cart_total_opt = '<option value="less_than">Less Than</option><option value="greater_than">Greater Than</option>';
			if ( currunt_val == '' ) {
				jQuery( this ).parent().parent().find( '#condition_logic' ).html( '' );
				jQuery( this ).parent().parent().find( '#condition_compareto' ).html( '' );
				return;
			}

			if ( currunt_val == 'cart_total' ) {
				jQuery( this ).parent().parent().find( '#condition_logic' ).html( cart_total_opt );
			} else {
				jQuery( this ).parent().parent().find( '#condition_logic' ).html( equal_not_opt );
			}

			var data = {
				action: 'cart_upsell_get_dropdown_content',
				currunt_val: currunt_val,
				nonce: nonce,
			};

			jQuery.ajax(
				{
					type: "post",
					url: ajaxurl,
					data: data,
					success: function(response) {
						jQuery( currunt_event ).parent().parent().find( '#condition_compareto' ).html( JSON.parse( response ) );
					}
				}
			);
			return false;

		}
	);

	jQuery( document ).on(
		'click',
		'.and_rule_group .cart_upsell_and_condition',
		function(){
			var append_row = '<tr><td><select name="condition_type[]" id="condition_type"><option value="">Add Condition...</option><option value="product">Product</option><option value="category">Category</option><option value="cart_total">Cart Total</option></select></td><td><select name="condition_logic[]" id="condition_logic"><option value=""></option></select></td><td><select name="condition_compareto[]" id="condition_compareto"><option value=""></option></select></td><td style="display:none;"><select name="condition_separater[]" id="condition_separater"><option value="*">Disabled</option></select></td><td valign="top"><input type="button" value="X" data-id="and_condition" class="cart_upsell_minus button"></td></tr>';

			jQuery( this ).parent().find( '.table_and_condition' ).append( append_row );
		}
	);

	jQuery( document ).on(
		'click',
		'.or_rule_group .cart_upsell_or_condition',
		function(){
			var append_row = '<tr><td><select name="condition_type[]" id="condition_type"><option value="">Add Condition...</option><option value="product">Product</option><option value="category">Category</option><option value="cart_total">Cart Total</option></select></td><td><select name="condition_logic[]" id="condition_logic"><option value=""></option></select></td><td><select name="condition_compareto[]" id="condition_compareto"><option value=""></option></select></td><td style="display:none;"><select name="condition_separater[]" id="condition_separater"><option value="*">Disabled</option></select></td><td valign="top"><input type="button" value="X" data-id="or_condition" class="cart_upsell_minus button"></td></tr>';

			jQuery( this ).parent().find( '.table_or_condition' ).append( append_row );
		}
	);

	jQuery( document ).on(
		'click',
		'#cart_upsell_section .cart_upsell_minus',
		function(){
			jQuery( this ).parent().parent().remove();
		}
	);

	function upsell_field_error(){
		jQuery( '.upsell_error_fields' ).html( 'Remove blank fields' );
		return false;
	}

	jQuery( document ).on(
		'click',
		'#cart_upsell_section #upsell_data_submit',
		function(){
			jQuery( '.upsell_error_fields' ).html( '' );
			var condition_and_data_array = [];
			var condition_or_data_array  = [];
			jQuery( "#cart_upsell_section .table_and_condition select" ).each(
				function(index) { if ( $( this ).val() == '' ) {
						return upsell_field_error(); } condition_and_data_array.push( $( this ).val() ) }
			);

			jQuery( "#cart_upsell_section .table_or_condition select" ).each(
				function(index) { if ( $( this ).val() == '' ) {
						return upsell_field_error(); } condition_or_data_array.push( $( this ).val() ) }
			);

			var content            = jQuery( "#cart_upsell_section #upsell_prd_content" ).val();
			var prd_url            = jQuery( "#cart_upsell_section #upsell_prd_url" ).val();
			var upsell_button_text = jQuery( "#cart_upsell_section #upsell_button_text" ).val();
			var bg_color           = jQuery( "#cart_upsell_section #upsell_bg_color" ).val();
			var content_color      = jQuery( "#cart_upsell_section #upsell_content_color" ).val();
			var button_color       = jQuery( "#cart_upsell_section #upsell_button_color" ).val();
			var button_bg_color    = jQuery( "#cart_upsell_section #upsell_button_bg_color" ).val();
			var tranps             = jQuery( "#cart_upsell_section #upsell_transparancy" ).val();
			var product_id         = jQuery( this ).attr( 'data-id' );
			var nonce              = jQuery( '#cart_upsell_section #_nonce' ).val();
			var data               = {
				action: 'cart_upsell_save_conditions',
				condition_and_data: condition_and_data_array.toString(),
				condition_or_data: condition_or_data_array.toString(),
				product_id: product_id,
				bg_color: bg_color,
				content_color: content_color,
				button_color: button_color,
				button_bg_color: button_bg_color,
				content: content,
				prd_url: prd_url,
				upsell_button_text: upsell_button_text,
				tranps: tranps,
				nonce: nonce,
			};
			jQuery.ajax(
				{
					type: "post",
					url: ajaxurl,
					data: data,
					beforeSend: function(response){
						jQuery( "#cart_upsell_section .upsell-loader" ).addClass( 'loader' );
					},
					complete: function(response){
						jQuery( "#cart_upsell_section .upsell-loader" ).removeClass( 'loader' );
					},
					success: function(response) {
						if ( 'success' === response ) {
							location.reload();
						}
					}
				}
			);
			return false;

		}
	);

})( jQuery );
