<?php
/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       www.skrotron.com
 * @since      1.0.7
 *
 * @package    Cart_Upsell_For_Woocommerce
 * @subpackage Cart_Upsell_For_Woocommerce/includes
 */

/**
 * Function belongs to cart upsell.
 */
function cart_upsell_ajaxurl() {
	echo '<script type="text/javascript">
            var ajaxurl = "' . esc_url( admin_url( 'admin-ajax.php' ) ) . '";
          </script>';
}
add_action( 'admin_enqueue_scripts', 'cart_upsell_ajaxurl' );

/**
 * Function belongs to cart upsell.
 */
function cart_upsell_front_ajaxurl() {
	echo '<script type="text/javascript">
            var ajaxurl = "' . esc_url( admin_url( 'admin-ajax.php' ) ) . '";
          </script>';
}
add_action( 'wp_enqueue_scripts', 'cart_upsell_front_ajaxurl' );

/**
 * Function belongs to cart upsell.
 *
 * @param      string $array       Values.
 */
function upsell_array_flatten( $array ) {
	if ( ! is_array( $array ) ) {
		return false;
	}
	$result = array();
	foreach ( $array as $key => $value ) {
		if ( is_array( $value ) ) {
			$result = array_merge( $result, upsell_array_flatten( $value ) );
		} else {
			$result[ $key ] = $value;
		}
	}
	return $result;
}

/**
 * Function belongs to cart upsell.
 */
function get_all_upsell_products() {
	$args     = array(
		'post_type'   => 'product',
		'post_status' => 'publish',
		'numberposts' => -1,
	);
	$products = get_posts( $args );
	return $products;
}

/**
 * Function belongs to cart upsell.
 */
function get_all_upsell_categories() {
	$orderby            = 'name';
	$order              = 'asc';
	$hide_empty         = false;
	$cat_args           = array(
		'orderby'    => $orderby,
		'order'      => $order,
		'hide_empty' => $hide_empty,
	);
	$product_categories = get_terms( 'product_cat', $cat_args );
	return $product_categories;
}

/**
 * Function belongs to cart upsell.
 *
 * @param      int $selected       Values.
 */
function get_upsell_cart_total_opt( $selected = '' ) {
	$option = '';
	$limit  = 5000;
	$step   = 50;
	$j      = 0;
	for ( $i = 0; $j <= $limit; $i++ ) {
		$option .= '<option value="' . $j . '"';
		$option .= ( $selected === $j ) ? 'selected ' : '';
		$option .= '>';
		$option .= wc_price( $j );
		$option .= '</option>';
		$j      += $step;
	}
	return $option;
}

/**
 * Function belongs to cart upsell.
 *
 * @param      string $selected       Values.
 */
function get_product_dd_cart_upsell( $selected = '' ) {
	$products = get_all_upsell_products();
	$option   = '';
	foreach ( $products as $product ) {
		$option .= '<option value="' . $product->ID . '"';
		$option .= ( $selected === $product->ID ) ? 'selected ' : '';
		$option .= '>';
		$option .= $product->post_title;
		$option .= '</option>';
	}
	return $option;
}

/**
 * Function belongs to cart upsell.
 *
 * @param      string $selected       Values.
 */
function get_category_dd_cart_upsell( $selected = '' ) {
	$categories = get_all_upsell_categories();
	$option     = '';
	foreach ( $categories as $category ) {
		$option .= '<option value="' . $category->term_id . '"';
		$option .= ( $selected === $category->term_id ) ? 'selected ' : '';
		$option .= '>';
		$option .= $category->name;
		$option .= '</option>';
	}
	return $option;
}


/**
 * Function belongs to cart upsell.
 *
 * @param      int $product_id       Values.
 */
function check_if_variable( $product_id ) {
	$id = wp_get_post_parent_id( $product_id );
	return $id;
}

/**
 * Function belongs to cart upsell.
 */
function get_cart_items_product_ids() {
	global $woocommerce;
	global $product;
	$items        = $woocommerce->cart->get_cart();
	$prd_id_array = array();
	foreach ( $items as $item => $values ) {
		$_product  = wc_get_product( $values['data']->get_id() );
		$prd_id    = $_product->get_id();
		$parent_id = check_if_variable( $prd_id );
		if ( $parent_id > 0 ) {
			$product_id = $parent_id;
		} else {
			$product_id = $prd_id;
		}
		$prd_id_array[] = $product_id;
	}
	return $prd_id_array;
}

/**
 * Function belongs to cart upsell.
 */
function get_cart_items_category_ids() {
	global $woocommerce;
	global $product;
	$items            = $woocommerce->cart->get_cart();
	$product_cats_ids = array();
	$cat_id_array     = array();
	foreach ( $items as $item => $values ) {
		$_product  = wc_get_product( $values['data']->get_id() );
		$prd_id    = $_product->get_id();
		$parent_id = check_if_variable( $prd_id );
		if ( $parent_id > 0 ) {
			$product_id = $parent_id;
		} else {
			$product_id = $prd_id;
		}

		$product_cats_ids[] = wc_get_product_term_ids( $product_id, 'product_cat' );
	}
	$cat_id_array = upsell_array_flatten( $product_cats_ids );
	return $cat_id_array;
}

/**
 * Function belongs to cart upsell.
 */
function get_cart_items_total() {
	global $woocommerce;
	return $woocommerce->cart->subtotal;
}

/**
 * Function belongs to cart upsell.
 *
 * @param      string $product       Values.
 */
function get_cart_upsell_check_and_condition( $product ) {
	$prd_id_array = get_cart_items_product_ids();
	$cat_id_array = get_cart_items_category_ids();
	$cart_total   = get_cart_items_total();

	$condition_data = get_post_meta( $product, 'cart_upsell_and_condition', true );
	if ( ! empty( $condition_data ) && 'null' !== $condition_data ) {
		$data_array       = explode( '*', $condition_data );
		$check_cat_cond   = array();
		$check_prd_cond   = array();
		$check_cart_total = array();
		foreach ( $data_array as $conditions ) {
			$condition_allarr = explode( ',', $conditions );
			$condition_array  = array_values( array_filter( $condition_allarr ) );
			if ( ! empty( $condition_array ) ) {
				list($condition_type, $condition_logic, $condition_compareto) = $condition_array;
				if ( 'category' === $condition_type && 'equal' === $condition_logic ) {
					$cat_id = intval( $condition_compareto );
					if ( in_array( $cat_id, $cat_id_array, true ) ) {
						$check_cat_cond[] = 1;
					} else {
						$check_cat_cond[] = 0;
					}
				}

				if ( 'category' === $condition_type && 'not_equal' === $condition_logic ) {
					$cat_id = intval( $condition_compareto );
					if ( ! in_array( $cat_id, $cat_id_array, true ) ) {
						$check_cat_cond[] = 1;
					} else {
						$check_cat_cond[] = 0;
					}
				}

				if ( 'product' === $condition_type && 'equal' === $condition_logic ) {
					$prd_id = intval( $condition_compareto );
					if ( in_array( $prd_id, $prd_id_array, true ) ) {
						$check_prd_cond[] = 1;
					} else {
						$check_prd_cond[] = 0;
					}
				}

				if ( 'product' === $condition_type && 'not_equal' === $condition_logic ) {
					$prd_id = intval( $condition_compareto );
					if ( ! in_array( $prd_id, $prd_id_array, true ) ) {
						$check_prd_cond[] = 1;
					} else {
						$check_prd_cond[] = 0;
					}
				}

				if ( 'cart_total' === $condition_type && 'less_than' === $condition_logic ) {
					$compare_total = intval( $condition_compareto );
					$cart_total    = intval( $cart_total );
					if ( $cart_total < $compare_total ) {
						$check_cart_total[] = 1;
					} else {
						$check_cart_total[] = 0;
					}
				}

				if ( 'cart_total' === $condition_type && 'greater_than' === $condition_logic ) {
					$compare_total = intval( $condition_compareto );
					$cart_total    = intval( $cart_total );
					if ( $cart_total > $compare_total ) {
						$check_cart_total[] = 1;
					} else {
						$check_cart_total[] = 0;
					}
				}
			}
		}

		if ( ! in_array( 0, $check_cat_cond, true ) && ! in_array( 0, $check_prd_cond, true ) && ! in_array( 0, $check_cart_total, true ) ) {
			return true;
		} else {
			return false;
		}
	} else {
		return true;
	}

}

/**
 * Function belongs to cart upsell.
 *
 * @param      string $product       Values.
 */
function get_cart_upsell_check_or_condition( $product ) {
	$prd_id_array = get_cart_items_product_ids();
	$cat_id_array = get_cart_items_category_ids();
	$cart_total   = get_cart_items_total();

	$condition_data = get_post_meta( $product, 'cart_upsell_or_condition', true );
	if ( ! empty( $condition_data ) && 'null' !== $condition_data ) {
		$data_array       = explode( '*', $condition_data );
		$check_cat_cond   = array();
		$check_prd_cond   = array();
		$check_cart_total = array();
		foreach ( $data_array as $conditions ) {
			$condition_allarr = explode( ',', $conditions );
			$condition_array  = array_values( array_filter( $condition_allarr ) );
			if ( ! empty( $condition_array ) ) {
				list($condition_type, $condition_logic, $condition_compareto) = $condition_array;
				if ( 'category' === $condition_type && 'equal' === $condition_logic ) {
					$cat_id = intval( $condition_compareto );
					if ( in_array( $cat_id, $cat_id_array, true ) ) {
						$check_cat_cond[] = 1;
					} else {
						$check_cat_cond[] = 0;
					}
				}

				if ( 'category' === $condition_type && 'not_equal' === $condition_logic ) {
					$cat_id = intval( $condition_compareto );
					if ( ! in_array( $cat_id, $cat_id_array, true ) ) {
						$check_cat_cond[] = 1;
					} else {
						$check_cat_cond[] = 0;
					}
				}

				if ( 'product' === $condition_type && 'equal' === $condition_logic ) {
					$prd_id = intval( $condition_compareto );
					if ( in_array( $prd_id, $prd_id_array, true ) ) {
						$check_prd_cond[] = 1;
					} else {
						$check_prd_cond[] = 0;
					}
				}

				if ( 'product' === $condition_type && 'not_equal' === $condition_logic ) {
					$prd_id = intval( $condition_compareto );
					if ( ! in_array( $prd_id, $prd_id_array, true ) ) {
						$check_prd_cond[] = 1;
					} else {
						$check_prd_cond[] = 0;
					}
				}

				if ( 'cart_total' === $condition_type && 'less_than' === $condition_logic ) {
					$compare_total = intval( $condition_compareto );
					$cart_total    = intval( $cart_total );
					if ( $cart_total < $compare_total ) {
						$check_cart_total[] = 1;
					} else {
						$check_cart_total[] = 0;
					}
				}

				if ( 'cart_total' === $condition_type && 'greater_than' === $condition_logic ) {
					$compare_total = intval( $condition_compareto );
					$cart_total    = intval( $cart_total );
					if ( $cart_total > $compare_total ) {
						$check_cart_total[] = 1;
					} else {
						$check_cart_total[] = 0;
					}
				}
			}
		}

		if ( in_array( 1, $check_cat_cond, true ) || in_array( 1, $check_prd_cond, true ) || in_array( 1, $check_cart_total, true ) ) {
			return true;
		} else {
			return false;
		}
	} else {
		return true;
	}

}
